translate.storage.versioncontrol.svn

Package translate :: Package storage :: Package versioncontrol :: Module svn |
[hide private]
[frames] | no frames]

# Module svn

source code

Classes | [hide private]
| svn Class to manage items under revision control of Subversion.

Functions | [hide private]
is_available() check if svn is installed | source code
get_version() return a tuple of (major, minor) for the installed subversion client | source code

Imports: run_command, GenericRevisionControlSystem